<?php

namespace Schaffen\ProductionOrder\ProductionOrder\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Schaffen\Core\Product\Models\ProductVarietyPack;
use Schaffen\Core\Traits\Audit;

class CompositeProduct extends Model
{
    //
    use SoftDeletes;
    use Audit;

    protected $primaryKey = "pcp_codigo";

    protected $table = "produto.produto_composicao_pcp";
    protected $fillable = [
        "pcp_codigo",
        "pcp_fk_pve_codigo_acabado",
        "pcp_fk_pve_codigo_materia_prima",
        "pcp_quantidade",
        "pcp_valor_unitario",
        "pcp_total",
        "pcp_controla_estoque",
        "created_at",
        "created_by"
    ];

    public $timestamps = false;

    const CREATED_AT = 'created_at';
    const CREATED_BY = 'created_by';
    const UPDATED_AT = 'updated_at';
    const UPDATED_BY = 'updated_by';
    const DELETED_AT = 'deleted_at';
    const DELETED_BY = 'deleted_by';


    public function finished_product()
    {
        return $this->belongsTo(ProductVarietyPack::class, 'pcp_fk_pve_codigo_materia_prima', 'pve_codigo')
            ->with('product_variety');
    }

    public function product_variety_pack()
    {
        return $this->hasOne(ProductVarietyPack::class, 'pve_codigo',
            'pcp_fk_pve_codigo_materia_prima')->with('product_variety');
    }

    public function production_order() 
    {
        return $this->hasMany(ProductionOrder::class, 'op_fk_pve_final', 'pcp_fk_pve_codigo_acabado');
    }
}
