<?php

namespace Schaffen\ProductionOrder\ProductionOrder\Models;

use Illuminate\Database\Eloquent\Model;
use Schaffen\WarehouseInventory\WarehouseInventory\Models\AccountInventory;
use Schaffen\Core\Product\Models\ProductVarietyPack;
use Schaffen\Core\Traits\Audit;

class ProductionOrderItem extends Model
{
    //
    use Audit;

    protected $fillable = [
        "opi_fk_pve_codigo",
        "opi_fk_op_codigo",
        "opi_quantidade_inicial",
        "opi_quantidade_final",
        "opi_valor_inicial",
        "opi_valor_final",
        "opi_controla_estoque",
        "opi_fk_loe_codigo_origem",
        "opi_fk_loe_codigo_destino",
        "opi_fk_cc_codigo_origem",
        "opi_fk_cc_codigo_destino"
    ];

    protected $table = "ordem_producao.ordem_producao_item";

    protected $primaryKey = "opi_codigo";

    const CREATED_AT = 'created_at';
    const CREATED_BY = 'created_by';

    public $timestamps = false;

    public function origin_inventory_po()
    {
        return $this->belongsTo(AccountInventory::class, "opi_fk_cc_codigo_origem", "cc_codigo");
    }

    public function destination_inventory_po()
    {
        return $this->belongsTo(AccountInventory::class, "opi_fk_cc_codigo_destino", "cc_codigo");
    }


    public function feedstock()
    {
        return $this->belongsTo(ProductVarietyPack::class, 'opi_fk_pve_codigo', 'pve_codigo');
    }
}
